This repo will hold a project that will be based on
[keras-gym](https://keras-gym.readthedocs.io/). It will be a ported from using
[keras](https://keras.io/) to using [JAX](https://jax.readthedocs.io/) for
function approximation.

-Kris
